Installation
============

**my-package** supports Python >= 3.7.

## Installing with `pip`

**my-package** is available [on PyPI](https://pypi.org/project/my-package/). Just run

```bash
pip install my-package
```

## Installing from source

To install **my-package** from source, first clone [the repository](https://github.com/allenai/python-package-template):

```bash
git clone https://github.com/allenai/python-package-template.git
cd python-package-template
```

Then run

```bash
pip install -e .
```
